#!/usr/bin/perl -w
# Copyright (c) 2013 Nicolas Mazziotta
# $Id: not versioned$
# This program is free software; you can redistribute it and/or
# modify it under the same terms as Perl itself.
#
# 

use strict;		

# Init

my ($name,$execpath,$suffix);

use File::Basename;

BEGIN {
  # find where the program has been installed
  my $filename = $0;
  eval {$filename = readlink $0 if -l $0};
  ($name,$execpath,$suffix) = fileparse($filename,qw/pl/);
	$execpath =~ s/\\/\//g if $^O =~ /^MSWin/;
}

use lib "$ENV{HOME}/lib/perl";
use lib "$execpath/lib";


my @words = ();
my $n = 0;
while (<>) {
	s/ / /g;
	s/’/'/g;
	s/\s*([';])\s*/$1 /g;
	foreach my $w (split(qr{\s+}, $_)) {
		next if $w =~ /^\s*\d+\s*$/;
		if ($w =~ /(\d+)\./) {
			push @words, qq{<lb n="$1"/>};
			next;
		};
		my $id="id" . ++$n;
		push @words, qq{<w xml:id="$id">$w</w>};
	}
}

&chunk_and_output(\@words);


#= Subroutine ========================================#  
sub chunk_and_output
#=====================================================#
{
	my ($words) = @_;
	my $threshold_warning = 2000;
	my $reset_at_lb = 0;
	my $current_count = 0;
	my $str_buffer = "";
	my $prefix = "";
	my $chunk_nr = 1;
	foreach my $w (@$words) {
		$reset_at_lb = 1 if ++$current_count >= $threshold_warning;
		if ($w =~ /<lb/ and $reset_at_lb) {
			$reset_at_lb = 0;
			$current_count = 0;
			&output($str_buffer, $chunk_nr++);
			$str_buffer = $w;
			next;
		} else {
			$str_buffer .= $w . "\n";
		}
	}
	&output($str_buffer, $chunk_nr++) if $str_buffer;
}

sub output {
	my ($text, $chunk_nr) = @_;
	open(OUT, ">", "chunk$chunk_nr.xml");
	print OUT &wrap_xml($text);
	close(OUT);
}

sub wrap_xml {
	my ($text) = @_;
	return qq{<?xml version='1.0' encoding='UTF-8'?><document xmlns="http://null.com/khartes/sample#">$text</document>};
}


__END__

# vim:sw=2 ts=2 

